import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import java.io.*;

public class Editor extends JFrame{
	private JMenuBar menueZeile;
	private JMenu fileMenue, extrasMenue, fontMenue, farbMenue;
	private JScrollPane roll; 
    private JEditorPane text;
    private File datei;
    private JMenuItem openItem;
    private JMenuItem exitItem;
    private JMenuItem timesItem;
    private JMenuItem helveticaItem;
    private JMenuItem weissItem;
    private JMenuItem gelbItem;

    private JMenu lookAndFeel;
    private JMenuItem metalItem, motifItem, windowsItem;
	private UIManager.LookAndFeelInfo lafs[];
	
	public Editor() {
		super("Editor mit Men");

		text = new JEditorPane();
		roll = new JScrollPane(text);
		getContentPane().add(roll, BorderLayout.CENTER);
		
		menueZeile = new JMenuBar();
		
		fileMenue = new JMenu("Datei");
		fileMenue.setMnemonic('D');

		openItem = new JMenuItem("ffnen");
		openItem.setMnemonic('f');
		fileMenue.add(openItem);
		openItem.addActionListener(new
			ActionListener() {
				public void actionPerformed(ActionEvent e) {
					openFile();
					if (datei != null) readText();
				}
			});

		exitItem = new JMenuItem("Beenden");
		exitItem.setMnemonic('B');
		exitItem.addActionListener(new
			ActionListener() {
				public void actionPerformed(ActionEvent e) {
					System.exit(0);
				}
			});
		fileMenue.add(exitItem);

		menueZeile.add(fileMenue);
								
		extrasMenue = new JMenu("Extras");
		extrasMenue.setMnemonic('E');
		fontMenue = new JMenu("Schriftart");
		fontMenue.setMnemonic('S');
		extrasMenue.add(fontMenue);
		timesItem = new JMenuItem("Times-Roman");
		timesItem.setMnemonic('T');
		timesItem.addActionListener(new
			ActionListener() {
				public void actionPerformed(ActionEvent e) {
					text.setFont(new Font("TimesRoman", Font.PLAIN, 14));
				}
			});
		fontMenue.add(timesItem);
		helveticaItem = new JMenuItem("Helvetica");
		helveticaItem.setMnemonic('H');
		helveticaItem.addActionListener(new
			ActionListener() {
				public void actionPerformed(ActionEvent e) {
					text.setFont(new Font("Helvetica", Font.PLAIN, 14));
				}
			});
		fontMenue.add(helveticaItem);

		farbMenue = new JMenu("Hintergrundfarbe");
		farbMenue.setMnemonic('H');
		extrasMenue.add(farbMenue);
		weissItem = new JMenuItem("Weiss");
		weissItem.setMnemonic('W');
		weissItem.addActionListener(new
			ActionListener() {
				public void actionPerformed(ActionEvent e) {
					text.setBackground(Color.white);
				}
			});
		farbMenue.add(weissItem);
		gelbItem = new JMenuItem("Gelb");
		gelbItem.setMnemonic('G');
		gelbItem.addActionListener(new
			ActionListener() {
				public void actionPerformed(ActionEvent e) {
					text.setBackground(Color.yellow);
				}
			});
		farbMenue.add(gelbItem);

		lafs = UIManager.getInstalledLookAndFeels();
		UIChooser ui = new UIChooser();

		lookAndFeel = new JMenu("Look & Feel");
		lookAndFeel.setMnemonic('L');
		extrasMenue.add(lookAndFeel);
		metalItem = new JMenuItem("Metal");
		metalItem.addActionListener(ui);
		motifItem = new JMenuItem("Motif");
		motifItem.addActionListener(ui);
		windowsItem = new JMenuItem("Windows");
		windowsItem.addActionListener(ui);
		lookAndFeel.add(metalItem);
		lookAndFeel.add(motifItem);
		lookAndFeel.add(windowsItem);

		menueZeile.add(extrasMenue);
				
		getContentPane().add(menueZeile, BorderLayout.NORTH);
		
		addWindowListener(new
			WindowAdapter() {
				public void windowClosing(WindowEvent e) {
					System.exit(0);
				}
			});
		setSize(300, 200);
		setVisible(true);

	}

	private void openFile() {
		JFileChooser fc = new JFileChooser();
		int returnCode = fc.showOpenDialog(this);
		if (returnCode == JFileChooser.APPROVE_OPTION)
			datei = fc.getSelectedFile();
		else
			datei = null;
	}

	private void readText() {
		String s;
		StringBuffer sb = new StringBuffer("");
		try {
			BufferedReader br = new BufferedReader(
				new FileReader(datei));
			while ((s = br.readLine()) != null) {
				sb.append(s);
				sb.append(System.getProperty("line.separator"));
			}
			text.setText(sb.toString());
			br.close();			
		}
		catch (Exception e) {
			JOptionPane.showMessageDialog(this,
				"Dokument kann nicht geffnet werden.", "Fehler",
				 JOptionPane.ERROR_MESSAGE);
		}

	}

	private void selUI(int ui) {
		try {
			UIManager.setLookAndFeel(lafs[ui].getClassName());
			SwingUtilities.updateComponentTreeUI(this);
		} catch (Exception e) {}
		text.setBackground(Color.white);
	}

	class UIChooser implements ActionListener {
		public void actionPerformed(ActionEvent e) {
			if (e.getSource() == metalItem) {
				selUI(0);
			} else if (e.getSource() == motifItem) {
				selUI(1);
			} else if (e.getSource() == windowsItem){
				selUI(2);
			}
		}
	}

	public static void main(String[] arg) {
		Editor mapp = new Editor();
	}

}