import javax.swing.*;
import javax.swing.event.*;
import java.awt.*;
import java.awt.event.*;

public class Prior extends JFrame implements ChangeListener, ItemListener, Runnable {
	private final String TXT1 = "Thread 1 luft mit Prioritt ";
	private final String TXT2 = "Thread 2 luft mit Prioritt ";
	private final int BREITE = 340;
	private final int SHOEHE = 140;
	private final int THOEHE = 50;
	private final int PAUSE  = 4;
	private final int SPRUNG = 1;
	private int x1, y1, x2, y2,			// akt. Schreibpos.
				tb1, tb2;				// Textbreite

	private Thread laufband1, laufband2;
	private int prior1 = 5, prior2 = 5;
	private boolean lb1an = true,
					lb2an = true;
	private static Object lock1, lock2;	// Monitore

	private JSlider ps1, ps2;
	private JCheckBox cb1, cb2;
	private Font arialFont;

	private JPanel steuerZone;
	private TPanel threadZone;

	public Prior() {
        super("Thread-Prioritten-Demo");

		steuerZone = new JPanel();
		threadZone = new TPanel();

 		ps1 = new JSlider(JSlider.HORIZONTAL,1,9,prior1);
 		ps1.setMajorTickSpacing(1);
 		ps1.setPaintLabels(true);
 		ps2 = new JSlider(JSlider.HORIZONTAL,1,9,prior2); 		
 		ps2.setMajorTickSpacing(1);
 		ps2.setPaintLabels(true);
		cb1 = new JCheckBox("Laufband von Thread 1", true);
		cb2 = new JCheckBox("Laufband von Thread 2", true);		
		ps1.setBorder(BorderFactory.createEmptyBorder(0, 5, 0, 0));
		ps2.setBorder(BorderFactory.createEmptyBorder(0, 5, 0, 0));
		cb1.setBorder(BorderFactory.createEmptyBorder(0, 10, 0, 0));
		cb2.setBorder(BorderFactory.createEmptyBorder(0, 10, 0, 0));

		steuerZone.setSize(BREITE, SHOEHE);
		threadZone.setSize(BREITE, THOEHE);
		steuerZone.setLayout(new GridLayout(2, 2));
		steuerZone.add(ps1);
		steuerZone.add(cb1);
		steuerZone.add(ps2);
		steuerZone.add(cb2);

		ps1.addChangeListener(this);
		ps2.addChangeListener(this);
		cb1.addItemListener(this);
		cb2.addItemListener(this);

		x2 = BREITE/2;
		y1 = 30;
		arialFont = new Font("Arial", Font.ITALIC, 16);
		threadZone.setFont(arialFont);
		tb1 = getFontMetrics(arialFont).stringWidth(TXT1)+40;
		y2 = 50;
		tb2 = getFontMetrics(arialFont).stringWidth(TXT2)+40;

        setSize(BREITE, SHOEHE+THOEHE);
        setResizable(false);
        Container cont = getContentPane();
		cont.setLayout(new GridLayout(2, 1));
		cont.add(steuerZone);
		cont.add(threadZone);
		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        show();

		laufband1 = new Thread(this, "Laufband1");
		laufband1.setPriority(prior1);
		laufband1.start();
		laufband2 = new Thread(this, "Laufband2");
		laufband2.setPriority(prior1);
		laufband2.start();
		lock1 = new Object();
		lock2 = new Object();
	}

	public void stateChanged(ChangeEvent e) {
	    JSlider sl = (JSlider) e.getSource();
	    if (sl == ps1) {
	        prior1 = sl.getValue();
	        laufband1.setPriority(prior1);
	    } else {
	        prior2 = sl.getValue();
	        laufband2.setPriority(prior2);
	    }
	}

	public void itemStateChanged(ItemEvent e) {
		if (e.getSource() == cb1) {
			lb1an = !lb1an;
			if (lb1an)
				synchronized(lock1) {lock1.notify();}
			else
				threadZone.repaint();
		} else {
			lb2an = !lb2an;
			if (lb2an)
				synchronized(lock2) {lock2.notify();}
			else
				threadZone.repaint();
		}
	}

	public void run() {
		while (true) {
			try {
				Thread.sleep(PAUSE);
				if (Thread.currentThread().getName().equals("Laufband1")) {
					synchronized(lock1) {
						while (!lb1an)
							lock1.wait();
					}
				}
				if (Thread.currentThread().getName().equals("Laufband2")) {
					synchronized(lock2) {
						while (!lb2an)
							lock2.wait();
					}
				}
			} catch(InterruptedException ie) {}

			if (Thread.currentThread().getName().equals("Laufband1")) {
				if (x1 + tb1 < 0)
					x1 = BREITE;
				else	
					x1 -= SPRUNG;
			}
			if (Thread.currentThread().getName().equals("Laufband2")) {
				if (x2 + tb2 < 0)
					x2 = BREITE;
				else	
					x2 -= SPRUNG;
			}
			threadZone.repaint();
		}
	}

	public static void main(String[] args) {
		new Prior();
	}

	class TPanel extends JPanel {
		public void paintComponent(Graphics g) {
			super.paintComponent(g);
			if (lb1an)
				g.drawString(TXT1+prior1, x1, y1);
			if (lb2an)
				g.drawString(TXT2+prior2, x2, y2);
		}
	}

}
